@@ -59,6 +59,7 @@ CREATE TABLE ofRoster (
   ask                   INTEGER         NOT NULL,
   recv                  INTEGER         NOT NULL,
   nick                  VARCHAR(255),
+  stanza                LONGVARCHAR,
   CONSTRAINT ofRoster_pk PRIMARY KEY (rosterID)
 );
 CREATE INDEX ofRoster_username_idx ON ofRoster (username);
@@ -211,6 +212,10 @@ CREATE TABLE ofMucRoom (
   canChangeNick       INTEGER       NOT NULL,
   canRegister         INTEGER       NOT NULL,
   allowpm             INTEGER       NULL,
+  fmucEnabled         INTEGER       NULL,
+  fmucOutboundNode    VARCHAR(255)  NULL,
+  fmucOutboundMode    INTEGER       NULL,
+  fmucInboundNodes    VARCHAR(4000) NULL,
   CONSTRAINT ofMucRoom_pk PRIMARY KEY (serviceID, name)
 );
 CREATE INDEX ofMucRoom_roomid_idx ON ofMucRoom (roomID);
@@ -319,7 +324,7 @@ CREATE TABLE ofPubsubItem (
   id                  VARCHAR(100)  NOT NULL,
   jid                 VARCHAR(1024) NOT NULL,
   creationDate        CHAR(15)      NOT NULL,
-  payload             VARCHAR(4000) NULL,
+  payload             CLOB          NULL,
   CONSTRAINT ofPubsubItem_pk PRIMARY KEY (serviceID, nodeID, id)
 );
 
@@ -372,7 +377,7 @@ INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
 INSERT INTO ofID (idType, id) VALUES (27, 1);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 30);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 33);
 
 // Entry for admin user
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
